@@ -113,17 +113,13 @@ def split_soft_returns(para: Paragraph) -> Paragraph:
     idx = 0
     for run in para.runs:
         while (newline_loc := run.text.find("\n")) != -1:
-            run_1, run_2 = split_run_at(para, run, newline_loc)
+            _, run_2 = split_run_at(run, newline_loc)
             run_2.text = run_2.text[1:]  # remove the newline char
 
             # move all runs prior to this one to a new paragraph above
             new_para = para.insert_paragraph_before(" ")
-            target_run = new_para.runs[0]
-            for source_run in reversed(para.runs[: idx + 1]):
-                target_run._r.addnext(source_run._r)
+            new_para._p[:] = para._p[: idx + 1]
 
-            # delete the empty run at the start of the prior paragraph
-            delete_run(target_run)
             idx = 0
         idx += 1
     return para
@@ -176,12 +172,11 @@ def compare_run_styles(run_1: Run, run_2: Run) -> bool:
     )
 
 
-def split_run_at(par: Paragraph, run: Run, split_at: int):
+def split_run_at(run: Run, split_at: int):
     """Splits a run at a specified index.
 
     Parameters
     ----------
-    par : Paragraph
     run : Run
     split_at : int
         Index of split location in the run.
@@ -191,47 +186,32 @@ def split_run_at(par: Paragraph, run: Run, split_at: int):
     list of runs
     """
     txt = run.text
-
-    if not isinstance(split_at, int):
-        raise ValueError("Split positions must be integer numbers")
-
     split_at %= len(txt)
-
     left, right = [txt[:split_at], txt[split_at:]]
 
-    run.text = left
-    # create second run
-    run_2 = par.add_run(right)
-    # move second run to be after first run
-    run._r.addnext(run_2._r)
+    run_2 = deepcopy(run._r)
 
-    # copy first run formatting to run two
-    copy_run_formatting(run, run_2)
+    run.text, run_2.text = left, right
+
+    # move second run to be after first run
+    run._r.addnext(run_2)
 
     return [run, run_2]
 
 
-def copy_run_formatting(run_from: Run, run_to: Run):
-    """Copies formatting from one run to another.
+def move_runs_to_end_of_para(para_from: Paragraph, para_to: Paragraph) -> None:
+    """Moves every run from para_from to the end of para_to.
 
     Parameters
     ----------
-    run_from, run_to : Run
+    para_from : Paragraph
+    para_to : Paragraph
     """
-    run_to_rPr = run_to._r.get_or_add_rPr()
-    run_to_rPr.addnext(deepcopy(run_from._r.get_or_add_rPr()))
-    run_to._r.remove(run_to_rPr)
-
-
-def move_runs_to_end_of_para(para_from: Paragraph, para_to: Paragraph) -> None:
-    for run in para_from:
-        para_to_end = para_to.runs[-1]._r
-        para_to_end.addnext(run)
-
+    para_to.extend(para_from)
     para_from.getparent().remove(para_from)
 
 
-def shade_columns(column, shade: str):
+def shade_cell(cell, shade: str) -> None:
     """Shades a list of cells in-place with a hex color value.
 
     Parameters
@@ -241,47 +221,39 @@ def shade_columns(column, shade: str):
     shade : str
         Hexadecimal color value
     """
-    for cell in column.cells:
-        tcPr = cell._tc.get_or_add_tcPr()
-        tcVAlign = OxmlElement("w:shd")
-        tcVAlign.set(qn("w:fill"), shade)
-        tcPr.append(tcVAlign)
+    tcPr = cell._tc.get_or_add_tcPr()
+    tcVAlign = OxmlElement("w:shd")
+    tcVAlign.set(qn("w:fill"), shade)
+    tcPr.append(tcVAlign)
 
 
-def delete_paragraph(paragraph: Paragraph):
+def delete_paragraph(paragraph: Paragraph) -> None:
     """Deletes a paragraph."""
     p = paragraph._element
     p.getparent().remove(p)
     p._p = p._element = None
 
 
-def delete_run(run: Run):
+def delete_run(run: Run) -> None:
     """Deletes a run."""
     p = run._r.getparent()
     p.remove(run._r)
 
 
-def clear_cell(cell: _Cell):
+def clear_cell(cell: _Cell) -> None:
     """Deletes every paragraph in a cell except for the first, and makes the first
-    paragraph contain only an empty run of text.
+    paragraph contain only an empty run of text. Removes shading (and all other)
+    element attributes, as well.
 
     Parameters
     ----------
     cell : _Cell
     """
-    if len(cell.paragraphs) > 1:
-        for paragraph in cell.paragraphs[1:]:
-            delete_paragraph(paragraph)
-    first_para = cell.paragraphs[0]
-    if len(first_para.runs) > 1:
-        for run in first_para.runs[1:]:
-            delete_run(run)
-    elif len(first_para.runs) == 0:
-        first_para.add_run("")
-    first_para.runs[0].text = ""
+    cell._tc.clear()
+    cell.add_paragraph("").add_run("")
 
 
-def highlight_cell_text(cell: _Cell, color: WD_COLOR_INDEX):
+def highlight_cell_text(cell: _Cell, color: WD_COLOR_INDEX) -> None:
     """Highlights all the text in a cell a given color. Used for
     providing linter warnings.
 
@@ -294,7 +266,7 @@ def highlight_cell_text(cell: _Cell, color: WD_COLOR_INDEX):
         highlight_paragraph_text(paragraph, color)
 
 
-def highlight_paragraph_text(para: Paragraph, color: WD_COLOR_INDEX):
+def highlight_paragraph_text(para: Paragraph, color: WD_COLOR_INDEX) -> None:
     """Highlights every run in a paragraph a given color.
 
     Parameters
@@ -306,6 +278,17 @@ def highlight_paragraph_text(para: Paragraph, color: WD_COLOR_INDEX):
         run.font.highlight_color = color
 
 
+def capitalize_paragraph(para: Paragraph) -> None:
+    """Capitalizes all text in a paragraph.
+
+    Parameters
+    ----------
+    para : Paragraph
+    """
+    for run in para.runs:
+        run.text = run.text.upper()
+
+
 def column_indexer(
     col_num: int, total_cells: int, col_count: int, skip_header: bool = True
 ) -> Generator[int, None, None]:
